<?php
#
# Author : Infowebs - Musiscore
# Release : 0.3
#
# Release History
# Code Release		: 0.1		17-07-2025	- Initial Alpha Release
# Code Release		: 0.2		20-07-2025	- Beta Release. Added extra fields to database.
# Code Release		: 0.3		22-07-2025	- Add coockie database 
# -----------------------------------------------------------------------

if (!function_exists('cmsms'))
	exit;

//$current_version = $oldversion;
$db = cmsms()->GetDB();
$taboptarray = array('mysql' => 'ENGINE=MyISAM');
$dict = NewDataDictionary($db);

switch ($oldversion)
{
	case "0.1":
	// add database fields for duration, pause, startdate, enddate, style, colors, position
		$flds = "
			duration I,
			pause I,
			startdate " . CMS_ADODB_DT . ",
			enddate " . CMS_ADODB_DT . ",
			style C(32),
			bordercolor C(6),
			backgroundcolor C(6),
			textcolor C(6),
			position C(32),
		";
		
		$sqlarray = $dict->AddColumnSQL(CMS_DB_PREFIX.'mod_iwpopupmanager',$flds,$taboptarray);
		$dict->ExecuteSQLArray($sqlarray);
		
	case "0.2":
	case "0.3":
	case "0.3.1":
	
}
?>